==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeAttachmentListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1VolumeAttachmentListFluent<A extends V1beta1VolumeAttachmentListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1beta1VolumeAttachment item);
    public A setToItems(int index,V1beta1VolumeAttachment item);
    public A addToItems(V1beta1VolumeAttachment... items);
    public A addAllToItems(Collection<V1beta1VolumeAttachment> items);
    public A removeFromItems(V1beta1VolumeAttachment... items);
    public A removeAllFromItems(Collection<V1beta1VolumeAttachment> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1VolumeAttachment> getItems();
    public List<V1beta1VolumeAttachment> buildItems();
    public V1beta1VolumeAttachment buildItem(int index);
    public V1beta1VolumeAttachment buildFirstItem();
    public V1beta1VolumeAttachment buildLastItem();
    public V1beta1VolumeAttachment buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1VolumeAttachmentBuilder> predicate);
    public A withItems(List<V1beta1VolumeAttachment> items);
    public A withItems(V1beta1VolumeAttachment... items);
    public Boolean hasItems();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> addNewItem();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> addNewItemLike(V1beta1VolumeAttachment item);
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> setNewItemLike(int index,V1beta1VolumeAttachment item);
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editItem(int index);
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editFirstItem();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editLastItem();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1VolumeAttachmentBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> withNewMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> editMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1VolumeAttachmentFluent<V1beta1VolumeAttachmentListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1beta1VolumeAttachmentListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeAttachmentListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1VolumeAttachmentListFluent<A extends V1beta1VolumeAttachmentListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1beta1VolumeAttachment item);
    public A setToItems(int index,V1beta1VolumeAttachment item);
    public A addToItems(V1beta1VolumeAttachment... items);
    public A addAllToItems(Collection<V1beta1VolumeAttachment> items);
    public A removeFromItems(V1beta1VolumeAttachment... items);
    public A removeAllFromItems(Collection<V1beta1VolumeAttachment> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1VolumeAttachment> getItems();
    public List<V1beta1VolumeAttachment> buildItems();
    public V1beta1VolumeAttachment buildItem(int index);
    public V1beta1VolumeAttachment buildFirstItem();
    public V1beta1VolumeAttachment buildLastItem();
    public V1beta1VolumeAttachment buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1VolumeAttachmentBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1VolumeAttachmentBuilder> predicate);
    public A withItems(List<V1beta1VolumeAttachment> items);
    public A withItems(V1beta1VolumeAttachment... items);
    public Boolean hasItems();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> addNewItem();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> addNewItemLike(V1beta1VolumeAttachment item);
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> setNewItemLike(int index,V1beta1VolumeAttachment item);
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editItem(int index);
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editFirstItem();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editLastItem();
    public V1beta1VolumeAttachmentListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1beta1VolumeAttachmentBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> withNewMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> editMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1VolumeAttachmentListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1VolumeAttachmentFluent<V1beta1VolumeAttachmentListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1beta1VolumeAttachmentListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
